%define		PYVER		2.5
%define		PVER		%(echo %{PYVER} | awk -F. '{print$1$2}')

Distribution:	CCux
Packager:	Christian Wasem <wasem@ccux-linux.de>
Name:		python%{PVER}
Version:	2.5.4
Release:	3
License:	Modified CNRI Open Source License
URL:		http://www.python.org
Group:		Development/Python
Source0:	Python-%{version}.tar.bz2
Source1:	html-2.5.tar.bz2
Patch0:		python-2.4.1-gdbm.patch
BuildRoot:	%{_tmppath}/%{name}-buildroot
Summary:	Python is an interpreted, interactive, object-oriented programming language.

Provides:	python(abi) = %{PYVER}
Provides:	python-abi = %{PYVER}
Provides:	python = %{version}-%{release}
Obsoletes:	python = 2.5.4-2
Obsoletes:	python = 2.5.2-1

#Automatically resolved build dependencies
BuildRequires: bzip2-devel
BuildRequires: coreutils
BuildRequires: db-devel
BuildRequires: gdbm-devel
BuildRequires: gettext-devel
BuildRequires: glibc-devel
BuildRequires: libX11-devel
BuildRequires: ncurses-devel
BuildRequires: openssl-devel
BuildRequires: readline-devel
BuildRequires: sqlite-devel
BuildRequires: tcl-devel
BuildRequires: tk-devel
BuildRequires: zlib-devel

%description
Python is an interpreted, interactive, object-oriented programming language.
It combines remarkable power with very clear syntax, and isn't difficult to learn.
It has modules, classes, exceptions, very high level data types, and dynamic typing.
There are interfaces to many system calls and libraries,
as well as to various windowing systems (Tk, Mac, MFC, GTK+, Qt, wxWindows).
New built-in modules are easily written in C or C++. Python is also usable as an
extension language for applications that need a programmable interface.
For more details see: http://www.python.org

%package	devel
Summary:	%{name} development headers.
Group:		Development/Python
Requires:	%{name} = %{version}-%{release}
Provides:	python-devel = %{version}-%{release}
Obsoletes:	python-devel = 2.5.4-2
Obsoletes:	python-devel = 2.5.2-1

%description	devel
Header and include files for developing applications with %{name}.

%package	doc
Summary:	Additional documents for %{name}.
Group:		Documentation
Requires:	%{name} = %{version}-%{release}
Provides:	python-doc = %{version}-%{release}
Obsoletes:	python-doc = 2.5.4-2
Obsoletes:	python-doc = 2.5.2-1

%description	doc
Additional documents for %{name}.

%post
ldconfig

%postun
ldconfig

%prep
%setup -q -n Python-%{version}
tar xfj %{SOURCE1}

# Get rid of crap
find -name "*~"|xargs rm -f

# Workaround to avoid confusing find-requires:
# don't ship the tests as executable files
chmod 0644 Lib/test/test_*.py

%build
topdir=`pwd`
%configure \
--enable-shared \
--with-gcc \
--with-cxx-main=gcc
make OPT="$CFLAGS" %{?_smp_mflags}

# Rebuild with new python, we need a link to a versioned python in the build directory
ln -s python python%{PYVER}
LD_LIBRARY_PATH=$topdir $topdir/python%{PYVER} Tools/scripts/pathfix.py -i "%{_bindir}/env python%{PYVER}" .
LD_LIBRARY_PATH=$topdir PATH=$PATH:$topdir make -s OPT="$CFLAGS" %{?_smp_mflags}

%install
# Cleaning Buildroot
rm -Rf $RPM_BUILD_ROOT

# Install
make install DESTDIR=$RPM_BUILD_ROOT

#make the binaries install side by side with the main python
pushd $RPM_BUILD_ROOT%_bindir
mv idle idle%{PYVER}
mv smtpd.py smtpd%{PYVER}.py
mv pydoc pydoc%{PYVER}
popd

# Fix the interpreter path
for fixed in $RPM_BUILD_ROOT%_bindir/{idle%{PYVER},pydoc%{PYVER},smtpd%{PYVER}.py}; do
    sed -i "s,#!/usr/bin/python,#!/usr/bin/python%{PYVER}," $fixed
    sed -i "s,#! /usr/bin/env python,#!/usr/bin/python%{PYVER}," $fixed
    sed -i "s,#!/usr/bin/python[0-9].[0-9][0-9].[0-9],#!/usr/bin/python%{PYVER}," $fixed
done

# Get rid of crap
find $RPM_BUILD_ROOT/ -name "*~"|xargs rm -f
find $RPM_BUILD_ROOT/ -name ".cvsignore"|xargs rm -f
find $RPM_BUILD_ROOT/ -name ".exe"|xargs rm -f

# We are shipping versionized python
rm $RPM_BUILD_ROOT%_bindir/python-config
rm $RPM_BUILD_ROOT%_bindir/python

# manpage
mv $RPM_BUILD_ROOT%_mandir/man1/python.1 $RPM_BUILD_ROOT%_mandir/man1/python%{PYVER}.1

# python's build is stupid and doesn't fail if extensions fail to build
# let's list a few that we care about...
for so in _bsddb.so _ctypes.so _curses.so _elementtree.so _sqlite3.so _ssl.so readline.so _hashlib.so zlib.so bz2.so pyexpat.so; do
    if [ ! -f $RPM_BUILD_ROOT%_libdir/python%{PYVER}/lib-dynload/$so ]; then
       echo "Missing $so!!!"
       exit 1
    fi
done

#Install html-documents
mkdir -p $RPM_BUILD_ROOT%_datadir/doc/%{name}-%{PYVER}/html
cp -Rf Python-Docs-%{PYVER}/* $RPM_BUILD_ROOT%_datadir/doc/%{name}-%{PYVER}/html
cp $RPM_BUILD_DIR/Python-%{version}/{README,LICENSE} $RPM_BUILD_ROOT%_datadir/doc/%{name}-%{PYVER}

rm -f $RPM_BUILD_ROOT%_libdir/python%{PYVER}/*.egg-info
rm -f $RPM_BUILD_ROOT%_libdir/python%{PYVER}/LICENSE.txt

%clean
rm -Rf $RPM_BUILD_ROOT
rm -Rf $RPM_BUILD_DIR/Python-*

%files
%defattr(-,root,root)
%_datadir/doc/%{name}-%{PYVER}/README
%_datadir/doc/%{name}-%{PYVER}/LICENSE
# bindir
%_bindir/idle%{PYVER}
%_bindir/pydoc%{PYVER}
%_bindir/python%{PYVER}
%_bindir/smtpd%{PYVER}.py
%_libdir/libpython%{PYVER}.so
%_libdir/libpython%{PYVER}.so.1.0
# libdir dirs
%_libdir/python%{PYVER}/bsddb
%_libdir/python%{PYVER}/compiler
%_libdir/python%{PYVER}/config
%_libdir/python%{PYVER}/ctypes
%_libdir/python%{PYVER}/curses
%_libdir/python%{PYVER}/distutils
%_libdir/python%{PYVER}/email
%_libdir/python%{PYVER}/encodings
%_libdir/python%{PYVER}/hotshot
%_libdir/python%{PYVER}/idlelib
%_libdir/python%{PYVER}/lib-dynload
%_libdir/python%{PYVER}/lib-tk
%_libdir/python%{PYVER}/logging
%_libdir/python%{PYVER}/plat-linux2
%_libdir/python%{PYVER}/site-packages
%_libdir/python%{PYVER}/sqlite3
%_libdir/python%{PYVER}/test
%_libdir/python%{PYVER}/wsgiref
%_libdir/python%{PYVER}/xml
# libdir files
%_libdir/python%{PYVER}/*.py
%_libdir/python%{PYVER}/*.pyc
%_libdir/python%{PYVER}/*.pyo
%_libdir/python%{PYVER}/pdb.doc
%_mandir

%files devel
%defattr(-,root,root)
%_bindir/python%{PYVER}-config
%_includedir

%files doc
%defattr(-,root,root)
%_datadir/doc/%{name}-%{PYVER}/html

%changelog
* Thu Oct 22 2009 Christian Wasem <wasem@ccux-linux.de> 2.5.4-3
- rebuild as python25 (preperation for new python)
* Sun May 03 2009 Christian Wasem <wasem@ccux-linux.de> 2.5.4-2
- build without /usr/bin/python and /usr/bin/python-config
* Wed Feb 25 2009 Karsten Brockmann <arcam@ccux-linux.de> 2.5.4-1
- Version update
* Sun May 18 2008 Karsten Brockmann <arcam@ccux-linux.de> 2.5.2-1
- Version update
* Fri Dec 21 2007 Christian Metzen <metzench@ccux-linux.de> 2.5.1-2
- rebuilt against tcl/tk 8.5.0
* Tue Apr 24 2007 Christian Metzen <metzench@ccux-linux.de> 2.5.1-1
- Version update
* Tue Sep 19 2006 Karsten Brockmann <arcam@ccux-linux.de> 2.5-1
- Version update
* Sat Apr 29 2006 Simon Schmeisser <mail_to_wrt@gmx.de> 2.4.3-1
- Update to version 2.4.3
* Wed Apr 12 2006 Christian Metzen <metzench@ccux-linux.de> 2.4.2-2
- Fixed Provides
* Fri Nov 18 2005 Christian Wasem <wasem@ccux-linux.de> 2.4.2-1
- Update to Version 2.4.2, removed wrong Obsoletes-Tag
* Wed Jun 29 2005 Christian Wasem <wasem@ccux-linux.de> 2.4.1-1
- Update to Version 2.4.1
